//+------------------------------------------------------------------+
//|                                              File Read Write.mq4 |
//|                      Copyright  2008, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net/"

// constant for _lopen function
#define OF_READ               0
#define OF_WRITE              1
#define OF_READWRITE          2
#define OF_SHARE_COMPAT       3
#define OF_SHARE_DENY_NONE    4
#define OF_SHARE_DENY_READ    5
#define OF_SHARE_DENY_WRITE   6
#define OF_SHARE_EXCLUSIVE    7

#import "kernel32.dll"
   int _lopen  (string path, int of);
   int _lcreat (string path, int attrib);
   int _llseek (int handle, int offset, int origin);
   int _lread  (int handle, string buffer, int bytes);
   int _lwrite (int handle, string buffer, int bytes);
   int _lclose (int handle);
#import

// _lopen  : Open indicated file. Return: description of the file.
// _lcreat : Create indicated file. return: description of the file.
// _llseek : Placing the pointer in open file. Return: 
// New deposition of the pointer.
// _lread  : Read indicated bytes from open file. Return: number of counted bytes; 0 - if end of the file.
// _lwrite : Write the data from the buffer to indicated file. Return: number of written bytes.
// _lclose : Close indicated file. Return: 0.
// If failure the finishing - all the functions returned
// HFILE_ERROR=-1.
 
// path   : path anf name of the file.
// of     : way of openning the file.
// attrib : 0 - reading or writing; 1 - reading only; 2 - hidden or  
// 3 - system file.
// handle : files descriptor..
// offset : Number of the byte for pointer to be moved.
// origin : Indicated the initial point and the direction of the movement: 0 - 
// forward from the beginning; 1 - from current position; 2 - back from the end of the file.
// buffer : buffer.
// bytes  : Number of the reading bytes.
 
// Way of the openning (parameter 'of'):
// int OF_READ            =0; // Open file for reading only
// int OF_WRITE           =1; // Open file for writing only
// int OF_READWRITE       =2; // Open file for read/write
// int OF_SHARE_COMPAT    =3; // Open the file for share network. 
// Any process can open this file any number of time. In any other regumen (not share network) 
// the function retrn HFILE_ERROR.
// int OF_SHARE_DENY_NONE =4; // Open the file in share network  
// without deny for reading/writing by the other process. If the file is tried to be open in  
// OF_SHARE_COMPAT regimen, the function return HFILE_ERROR.
// int OF_SHARE_DENY_READ =5; // Open the file in share network with  
// deny for reading/writing by the other process. If the file is tried to be open in  
// OF_SHARE_COMPAT flag and/or with OF_READ or OF_READWRITE, the fnction 
// return HFILE_ERROR.
// int OF_SHARE_DENY_WRITE=6; // the same but with writing deny.
// int OF_SHARE_EXCLUSIVE =7; // Deny the current and other process for 
// access to this file in reading/writing. It is possible to open the file 
// 1 time only (by current process). Other attempt to open will be failed.
//+------------------------------------------------------------------+
//|                            |
//+------------------------------------------------------------------+
string ReadFile (string path) 
  {
    int handle=_lopen (path,OF_READ);           
    if(handle<0) 
      {
        Print("Error to open the file",path); 
        return ("");
      }
    int result=_llseek (handle,0,0);      
    if(result<0) 
      {
        Print("Error to indicate the pointer" ); 
        return ("");
      }
    string buffer="";
    string char1="x";
    int count=0;
    result=_lread (handle,char1,1);
    while(result>0) 
      {
        buffer=buffer+char1;
        char1="x";
        count++;
        result=_lread (handle,char1,1);
     }
    result=_lclose (handle);              
    if(result<0)  
      Print("Error to close the file",path);
    return (buffer);
  }
 
//+------------------------------------------------------------------+
//|                          |
//+------------------------------------------------------------------+
void WriteFile (string path, string buffer) 
  {
    int count=StringLen (buffer); 
    int result;
    int handle=_lopen (path,OF_WRITE);
    if(handle<0) 
      {
        handle=_lcreat (path,0);
        if(handle<0) 
          {
            Print ("Error to create the file",path);
            return;
          }
        result=_lclose (handle);
     }
    handle=_lopen (path,OF_WRITE);               
    if(handle<0) 
      {
        Print("Error to open the file",path); 
        return;
      }
    result=_llseek (handle,0,0);          
    if(result<0) 
      {
        Print("Error to indicate the pointer"); 
        return;
      }
    result=_lwrite (handle,buffer,count); 
    if(result<0)  
        Print("Error to write in the file ",path," ",count,"byte ");
    result=_lclose (handle);              
    if(result<0)  
        Print("Error to close the file ",path);
  }
//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
  {
//----
    string buffer=ReadFile("C:\\Text.txt");
    int count=StringLen(buffer);
    Print("read byte:",count);
    WriteFile("C:\\Text2.txt",buffer);   
//----
   return(0);
  }
//+------------------------------------------------------------------+